@@ -25,6 +25,7 @@
 #include <QGpgME/Protocol>
 #include <QGpgME/SignKeyJob>
 
+#include <QDate>
 #include <QEventLoop>
 
 #include <gpgme++/key.h>
@@ -88,7 +89,6 @@ CertifyCertificateCommand::Private::Private(CertifyCertificateCommand *qq, KeyLi
       dialog(),
       job()
 {
-
 }
 
 CertifyCertificateCommand::Private::~Private()
@@ -134,7 +134,6 @@ CertifyCertificateCommand::CertifyCertificateCommand(const std::vector<GpgME::Us
 
 void CertifyCertificateCommand::Private::init()
 {
-
 }
 
 CertifyCertificateCommand::~CertifyCertificateCommand()
@@ -142,34 +141,6 @@ CertifyCertificateCommand::~CertifyCertificateCommand()
     qCDebug(KLEOPATRA_LOG);
 }
 
-void CertifyCertificateCommand::setCertificationExportable(bool on)
-{
-    Q_UNUSED(on)
-}
-
-void CertifyCertificateCommand::setCertificationRevocable(bool on)
-{
-    Q_UNUSED(on)
-}
-
-void CertifyCertificateCommand::setCertifyingKey(const Key &signer)
-{
-    Q_UNUSED(signer)
-}
-
-void CertifyCertificateCommand::setUserIDs(const std::vector<UserID> &uids)
-{
-    d->uids = uids;
-    if (!uids.empty() && d->key().isNull()) {
-        setKey(uids.front().parent());
-    }
-}
-
-void CertifyCertificateCommand::setUserID(const UserID &uid)
-{
-    setUserIDs(std::vector<UserID>(1, uid));
-}
-
 void CertifyCertificateCommand::doStart()
 {
 
@@ -224,7 +195,7 @@ void CertifyCertificateCommand::doStart()
     }
     const Key &key = keys.front();
 
-    for (const UserID &uid : qAsConst(d->uids))
+    for (const UserID &uid : std::as_const(d->uids))
         if (qstricmp(uid.parent().primaryFingerprint(), key.primaryFingerprint()) != 0) {
             qCWarning(KLEOPATRA_LOG) << "User-ID <-> Key mismatch!";
             d->finished();
@@ -256,7 +227,7 @@ void CertifyCertificateCommand::Private::slotDialogRejected()
 void CertifyCertificateCommand::Private::slotResult(const Error &err)
 {
     if (!err && !err.isCanceled() && dialog && dialog->exportableCertificationSelected() && dialog->sendToServer()) {
-        ExportOpenPGPCertsToServerCommand *const cmd = new ExportOpenPGPCertsToServerCommand(key());
+        auto const cmd = new ExportOpenPGPCertsToServerCommand(key());
         cmd->start();
     } else if (!err) {
         information(i18n("Certification successful."),
@@ -294,6 +265,17 @@ void CertifyCertificateCommand::Private::slotCertificationPrepared()
     // This also came with 1.14.0
     job->setDupeOk(true);
 #endif
+#ifdef QGPGME_SUPPORTS_TRUST_SIGNATURES
+    if (dialog->trustSignatureSelected() && !dialog->trustSignatureDomain().isEmpty()) {
+        // always create level 1 trust signatures with complete trust
+        job->setTrustSignature(TrustSignatureTrust::Complete, 1, dialog->trustSignatureDomain());
+    }
+#endif
+#ifdef QGPGME_SUPPORTS_SIGNATURE_EXPIRATION
+    if (!dialog->expirationDate().isNull()) {
+        job->setExpirationDate(dialog->expirationDate());
+    }
+#endif
 
     if (const Error err = job->start(key())) {
         slotResult(err);
