@@ -61,7 +61,7 @@ NewResultPage::Private::Private(NewResultPage *qq) : q(qq), m_lastErrorItemIndex
     m_hideProgressTimer.setSingleShot(true);
 
     QBoxLayout *const layout = new QVBoxLayout(q);
-    QWidget *const labels = new QWidget;
+    auto const labels = new QWidget;
     m_progressLabelLayout = new QVBoxLayout(labels);
     layout->addWidget(labels);
     m_progressBar = new QProgressBar;
@@ -118,7 +118,7 @@ void NewResultPage::Private::started(const std::shared_ptr<Task> &task)
     if (tag.isEmpty()) {
         label->setText(i18nc("number, operation description", "Operation %1: %2", m_resultList->numberOfCompletedTasks() + 1, task->label()));
     } else {
-        label->setText(i18nc("tag( \"OpenPGP\" or \"CMS\"),  operation description", "%1: %2", tag, task->label()));
+        label->setText(i18nc(R"(tag( "OpenPGP" or "CMS"),  operation description)", "%1: %2", tag, task->label()));
     }
 }
 
@@ -169,7 +169,7 @@ QLabel *NewResultPage::Private::labelForTag(const QString &tag)
     if (QLabel *const label = m_progressLabelByTag.value(tag)) {
         return label;
     }
-    QLabel *label = new QLabel;
+    auto label = new QLabel;
     label->setTextFormat(Qt::RichText);
     label->setWordWrap(true);
     m_progressLabelLayout->addWidget(label);
