@@ -7,8 +7,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef __KLEOPATRA_CRYPTO_GUI_RESULTLISTWIDGET_H__
-#define __KLEOPATRA_CRYPTO_GUI_RESULTLISTWIDGET_H__
+#pragma once
 
 #include <QWidget>
 
@@ -62,4 +61,3 @@ private:
 }
 }
 
-#endif // __KLEOPATRA_CRYPTO_GUI_RESULTLISTWIDGET_H__
