@@ -8,11 +8,11 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef __KLEOPATRA_DIALOGS_REVOKECERTIFICATIONWIDGET_H__
-#define __KLEOPATRA_DIALOGS_REVOKECERTIFICATIONWIDGET_H__
+#pragma once
 
 #include <QWidget>
 
+#include <memory>
 #include <vector>
 
 namespace GpgME
@@ -61,4 +61,3 @@ private:
 
 } // namespace Kleo
 
-#endif // __KLEOPATRA_DIALOGS_REVOKECERTIFICATIONWIDGET_H__
